@@ -1,3 +1,3 @@
 from .kelly import kelly
 
-__all__ = [kelly]
+__all__ = ["kelly"]
