@@ -1,4 +1,3 @@
-from __future__ import annotations
 from decimal import Decimal
 from ..odds import Odds
 
@@ -25,14 +24,13 @@ def kelly(true_odds: Odds, market_odds: Odds, bank: Decimal) -> Decimal:
         Decimal('0.00')
     """
 
-    p = true_odds.to_probability()
-    q = 1 - p
-    b = market_odds.to_one()
+    p: Decimal = true_odds.to_probability()
+    q: Decimal = 1 - p
+    odds: Decimal = market_odds.to_one()
 
-    kelly_percentage = (b * p - q) / b
-    stake = round(
-        (Decimal(bank * kelly_percentage) if kelly_percentage > 0.0 else Decimal(0.00)),
-        2,
-    )
+    edge: Decimal = (odds * p) - q
+    kelly: Decimal = edge / odds
+
+    stake: Decimal = round(bank * max(kelly, Decimal("0")), 2)
 
     return stake
